@@ -1,18 +1,37 @@
 import ast
+import logging
 
 from django.conf import settings
 from paypal.standard.ipn.signals import valid_ipn_received
-from paypal.standard.models import ST_PP_COMPLETED
-from plans.models import Order, Pricing, UserPlan
+from paypal.standard.models import ST_PP_COMPLETED, ST_PP_PENDING
+from plans.models import Order
 
 from .models import PayPalPayment
 
 
+logger = logging.getLogger(__name__)
+
+
 def parse_custom(custom):
     custom = custom.replace("null", "None")
     return ast.literal_eval(custom)
 
 
+def get_order_id(ipn_obj):
+    try:
+        custom = parse_custom(ipn_obj.custom)
+        return custom["first_order_id"]
+    except SyntaxError:
+        logger.error(
+            "Can't parse custom data",
+            extra={
+                "custom_data": ipn_obj.custom,
+                "ipn_obj": ipn_obj,
+            },
+        )
+        return ipn_obj.item_number
+
+
 def receive_ipn(sender, **kwargs):
     print("paypal hook")
     ipn_obj = sender
@@ -26,13 +45,28 @@ def receive_ipn(sender, **kwargs):
         # Not a subscription
         return None
 
-    custom = parse_custom(ipn_obj.custom)
-    order = Order.objects.get(pk=custom["first_order_id"])
+    order = Order.objects.get(pk=get_order_id(ipn_obj))
     print("Order: ", order.id)
-    user_plan = UserPlan.objects.get(pk=custom["user_plan_id"])
+    user_plan = order.user.userplan
 
-    if ipn_obj.is_subscription_cancellation() and hasattr(user_plan, "recurring"):
-        user_plan.recurring.delete()
+    if ipn_obj.is_subscription_cancellation():
+        if user_plan and hasattr(user_plan, "recurring"):
+            if str(user_plan.recurring.token) == str(ipn_obj.subscr_id):
+                user_plan.recurring.delete()
+            else:
+                logger.warning(
+                    "Recurring user plan not found by ID, can't cancell subscription",
+                    extra={
+                        "recurring_token": user_plan.recurring.token,
+                        "ipn_token": ipn_obj.subscr_id,
+                        "recurring": user_plan.recurring,
+                        "ipn_obj": ipn_obj,
+                    },
+                )
+        return None
+    elif ipn_obj.is_subscription_payment() and ipn_obj.payment_status == ST_PP_PENDING:
+        # Pending status
+        return None
     elif (
         ipn_obj.is_subscription_payment() and ipn_obj.payment_status == ST_PP_COMPLETED
     ):
@@ -55,13 +89,13 @@ def receive_ipn(sender, **kwargs):
         # is allowed.
 
         # Undertake some action depending upon `ipn_obj`.
-        pricing = Pricing.objects.get(pk=custom["pricing_id"])
-        if order.status == Order.STATUS.COMPLETED:
+        if order.status != Order.STATUS.NEW:
             order = Order.objects.create(
                 user=user_plan.user,
                 plan=user_plan.plan,
-                pricing=pricing,
+                pricing=order.pricing,
                 amount=ipn_obj.mc_gross,
+                tax=order.tax,
                 currency=ipn_obj.mc_currency,
             )
         user_plan.set_plan_renewal(
@@ -77,7 +111,13 @@ def receive_ipn(sender, **kwargs):
         )  # use the new order
         order.complete_order()
         return paypal_payment
-    raise Exception(f"IPN with unknown status: {ipn_obj}")
+    logger.error(
+        "IPN with unknown status",
+        extra={
+            "ipn_obj": ipn_obj,
+            "ipn_status": ipn_obj.payment_status,
+        },
+    )
 
 
 valid_ipn_received.connect(receive_ipn)
